gpgLabs
=======

Tutorials and examples for applied geophysics!

.. image:: https://travis-ci.org/ubcgif/gpgLabs.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/ubcgif/gpgLabs

.. image:: http://mybinder.org/badge.svg
    :alt: Binder
    :target: http://mybinder.org:/repo/ubcgif/gpgLabs

These notebooks supplement material in the `gpg <http://gpg.geosci.xyz>`_
and are used in the applied geophysics course `EOSC 350 <http://eosc350.geosci.xyz>`_ at UBC.

Notes for Contributors
----------------------

- Please "restart and clear all output" when committing notebooks. This ensures users start with a clean notebook.

..image:: images/restartandclearoutput.png
    :alt: restart and clear all output

- For new notebooks, please add a link to `index.ipynb <https://github.com/ubcgif/gpgLabs/blob/master/index.ipynb>`_
  .. image:: images/indexnotebook.png
    :alt: index notebook

- All notebooks committed to this repository are tested on `TravisCI <https://travis-ci.org/ubcgif/gpgLabs>`_. If dependencies need to be updated, they can be added to `requirements.txt <https://github.com/ubcgif/gpgLabs/blob/master/requirements.txt>`_

- To update the notebooks hosted on `binders <http://mybinder.org:/repo/ubcgif/gpgLabs>`_, go to `mybinder.org <http://mybinder.org>`_ and enter "https://github.com/ubcgif/gpgLabs" in the **Build a repository** field.
